{% load streamfield_tags %}
{% block streamblock_form %}
<div class="block-fields">
    {% for f in form %}
        {% if f.value %}
        <div class="block-fields__field-{{ f.name }}">
        <span class="block-fields__label">{{ f.label }}:</span>
        {% format_field f %}
        </div>
        {% endif %}
    {% endfor %}
</div>
{% endblock streamblock_form %}