<div style="padding: 15px; background-color: #ffad00; margin: 20px; text-align: center;">
    Add template <span style="color: white">"{{ block_tmpl }}"</span> for block: <span style="color: white">"{{ model_str }}"</span> with context variable <span style="color: white">block_content</span> as model object or as model objects list.
</div>